@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env
 #############################################################################
 ##
 ## file :       arrays.py
@@ -44,7 +44,7 @@ from future import standard_library
 standard_library.install_aliases()
 from builtins import zip
 from builtins import map
-from builtins import str
+#from builtins import str
 from builtins import range
 from future.utils import raise_
 from builtins import object
