@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env
 """
 #############################################################################
 ##
@@ -47,7 +47,7 @@ from __future__ import absolute_import
 from future import standard_library
 
 standard_library.install_aliases()
-from builtins import str
+#from builtins import str
 from builtins import range
 from builtins import object
 from past.utils import old_div
