@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-from builtins import str
+#from builtins import str
 from PyQt4 import Qt
 import fandango as fn
 import fandango.qt as fqt
