@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env python
 """
 #############################################################################
 ##
@@ -54,7 +54,7 @@ from __future__ import division
 from builtins import next
 from builtins import map
 from builtins import zip
-from builtins import str
+#from builtins import str
 from builtins import range
 from builtins import object
 from past.utils import old_div
@@ -348,7 +348,7 @@ class ThreadDict(dict):
         periods shall be specified in seconds
         period=0 means that attribute will be updated every timewait*length
         """
-        if not dict.has_key(self, key):
+        if key not in self:
             self.parent.__setitem__(self, key, value)
         if key not in self._threadkeys:
             self._threadkeys.append(key)
@@ -420,7 +420,7 @@ class ThreadDict(dict):
 
     @self_locked
     def has_key(self, key):
-        return dict.has_key(self, key)
+        return key in self
 
     @self_locked
     def __iter__(self):
@@ -533,7 +533,7 @@ class CaselessDict(dict):
 
     def __getitem__(self, key):
         key = str(key)
-        if dict.has_key(self, key):
+        if key in self:
             return dict.__getitem__(self, key)
         return dict.__getitem__(self, key.lower() if hasattr(key, "lower") else key)
 
@@ -547,7 +547,7 @@ class CaselessDict(dict):
 
     def has_key(self, key):
         key = str(key)
-        return dict.has_key(self, key.lower() if hasattr(key, "lower") else key)
+        return key.lower() in self if hasattr(key, "lower") else key
 
     def get(self, key, def_val=None):
         key = str(key)
