@@ -42,7 +42,7 @@ standard_library.install_aliases()
 from builtins import filter
 from builtins import zip
 from builtins import map
-from builtins import str
+#from builtins import str
 from builtins import range
 from builtins import object
 from past.utils import old_div
