@@ -5,7 +5,7 @@ from future import standard_library
 
 standard_library.install_aliases()
 from builtins import filter
-from builtins import str
+#from builtins import str
 from builtins import range
 from future.utils import raise_
 from past.utils import old_div
