@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env python
 """ @if gnuheader
 #############################################################################
 ##
@@ -43,7 +43,7 @@ from future import standard_library
 standard_library.install_aliases()
 from builtins import filter
 from builtins import map
-from builtins import str
+#from builtins import str
 from builtins import range
 from future.utils import raise_
 import time, traceback, os, sys, threading, datetime
