@@ -47,7 +47,7 @@ from __future__ import print_function
 
 # python imports
 from builtins import zip
-from builtins import str
+#from builtins import str
 from builtins import object
 import time, re, os, traceback, threading
 
