@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.5
+#!/usr/bin/env python
 """
 #############################################################################
 ##
@@ -45,7 +45,7 @@ from future import standard_library
 
 standard_library.install_aliases()
 from builtins import zip
-from builtins import str
+#from builtins import str
 from builtins import range
 from past.utils import old_div
 from builtins import object
